# SOCCERNETV2

wget --no-check-certificate --content-disposition --user EDNYlLNTDqB0yqF --ask-password  https://exrcsdrive.kaust.edu.sa/exrcsdrive/public.php/webdav/2_HQ.mkv

curl -u "EDNYlLNTDqB0yqF:owncloud" https://exrcsdrive.kaust.edu.sa/exrcsdrive/public.php/webdav/1_HQ.mkv --output 1_HQ.mkv


mkdir "england_epl"
mkdir "england_epl/2014-2015"
mkdir "england_epl/2014-2015/2015-02-21 - 18-00 Crystal Palace 1 - 2 Arsenal"
curl -u "B72R7dTu1tZtIst:SoccerNet" "https://exrcsdrive.kaust.edu.sa/exrcsdrive/public.php/webdav/england_epl/2014-2015/2015-02-21%20-%2018-00%20Crystal%20Palace%201%20-%202%20Arsenal/1_HQ.mkv" --output "england_epl/2014-2015/2015-02-21 - 18-00 Crystal Palace 1 - 2 Arsenal/1_HQ.mkv"

<!-- https://exrcsdrive.kaust.edu.sa/exrcsdrive/index.php/s/B72R7dTu1tZtIst -->